#!/bin/busybox sh

usage() {
    echo "Usage:"
    echo "  $0 [options] <target device file name>"
    echo "Options:"
    echo "  -h"
    echo "     Show this help message."
    echo "  -t"
    echo "     flash type: nand, nor, ubi, emmc"
    echo
    echo "  device"
    echo "     partition to be erased"
    echo
    echo " Exit codes:"
    echo "   0:  Success."
    echo "   1:  Invalid arguments."
}

FLASH_TYPE=

while getopts "ht:" option; do
    case $option in
        h)
            usage
            exit 0
            ;;
        t)
            FLASH_TYPE="$OPTARG"
            ;;
        \?)
            usage
            exit 1
            ;;
    esac
done

shift $((OPTIND - 1))

DEVICE="$1"

case "$FLASH_TYPE" in
    nand|nor)
        # get the char device
        DEVICE=$(echo $DEVICE | sed 's/mtdblock/mtd/')
        ;;
    emmc|ubi)
        ;;
    *)
        echo "ERROR unknown flash type $FLASH_TYPE"
        ;;
esac

if [ -z "$DEVICE" ] || [ ! -w "$DEVICE" ] ; then
    echo "ERROR missing device node $DEVICE"
    usage
    exit 1
fi

erase_image()
{
    case $FLASH_TYPE in
        nand)
            exec "$RESCUE_ROOT_DIR"/usr/sbin/flash_erase $DEVICE 0 0
            ;;
        emmc|nor)
            exec "$RESCUE_ROOT_DIR"/bin/dd if=/dev/zero of="$DEVICE"
            ;;
        ubi)
            exec "$RESCUE_ROOT_DIR"/usr/sbin/ubiupdatevol "$DEVICE" --truncate
            ;;
    esac
}

erase_image
exit 0 # not reached
