#!/bin/busybox sh

strip_spaces() (
    STRIP_RE='s/^[[:space:]]*\([^[:space:]].*[^[:space:]]\)[[:space:]]*$/\1/g'
    printf "%s" "$1" | sed -e "$STRIP_RE"
)

matches_string() {
    case "$2" in
        $1) return 0;;
        *) return 1;;
    esac
}

parse_configuration() {
    FILENAME=$1
    shift
    VARIABLES="$@"

    if [ ! -r "$FILENAME" ]; then
        echo "Can not read $FILENAME"
        return 1
    fi

    if [ "${VERBOSITY:-0}" -gt 0 ]; then
        echo "  Parsing $FILENAME";
    fi

    for v in $VARIABLES; do
        eval "$v="
    done

    while IFS="" read config_line; do
        # Ignore comments and empty lines, and check the line format
        CLEAN_LINE="${config_line%%#*}"
        CLEAN_LINE="$(strip_spaces "$CLEAN_LINE")"
        if [ -z "$CLEAN_LINE" ]; then
            continue
        fi

        if ! matches_string "*=*" "$CLEAN_LINE"; then
            printf "ERROR: could not parse line:\n%s\n" "$CLEAN_LINE"
            return 1
        fi

        # Extract the variable name and the value.

        VARIABLE_NAME="$(strip_spaces "${CLEAN_LINE%%=*}")"
        VALUE="$(strip_spaces "${CLEAN_LINE#*=}")"

        # Verify if the variable in the file is one of the variables being
        # parsed, and set it.

        VALID_VARIABLE=0
        for v in $VARIABLES; do
            if [ "$VARIABLE_NAME" = "$v" ]; then
                # TODO: CHECK FOR PREVIOUS VALUE (DUPLICATED VARIABLES)
                eval "$v=\"$VALUE\""
                VALID_VARIABLE=1
            fi
        done

        if [ $VALID_VARIABLE -eq 0 ]; then
            printf "ERROR: %s is not a valid variable, in file:\n  %s\n"\
                "$VARIABLE_NAME" "$FILENAME"
            return 2
        fi

    done < "$FILENAME"

    for v in $VARIABLES; do
        VALUE="$(eval "printf \"%s\" \"\$$v\"")"
        if [ "${VERBOSITY:-0}" -gt 0 ]; then
            printf "    %s = %s\n" "$v" "$VALUE"
        fi
    done
}
